import { documentsList,findDataInfo } from '../../api/documentManagement'


export default{
    data(){
        return{
            params:{
                lang:"",
                type: 1  // 服务条款类型：数字1
            },
            infoParams:{
                id:"",
                lang:"",
            },
            // 存储从后端获取的文档内容
            info: "",
            // 加载状态
            loading: false
        }
    },
    mounted(){
        this.params.lang = this.$i18n?.locale || 'zh'
        this.fetchDocumentsList(this.params)
    },
    methods:{
        /**
         * 获取文档列表
         */
        async fetchDocumentsList(){
            try {
                this.loading = true
            const res = await documentsList(this.params)
                console.log('文档列表:', res)
              
                if (res && res.code === 200 && res.data && res.data.length > 0) {
                    console.log('请求参数:',  res.data)
                    this.infoParams.id = res.data[0].id
                    this.infoParams.lang = this.$i18n?.locale || 'zh'
                 
                    
                    if (this.infoParams.id && this.infoParams.lang) {
                        await this.fetchDocumentsInfo()
                    }
                } else {
                    console.warn('未获取到文档列表数据')
                    this.info = ""
                }
            } catch (error) {
                console.error('获取文档列表失败:', error)
                this.info = ""
            } finally {
                this.loading = false
            }
        },
        
        /**
         * 获取具体文档内容
         */
        async fetchDocumentsInfo(){
            try {
                if (!this.infoParams.id) {
                    console.warn('文档ID为空，无法获取文档内容')
                    return
                }
                
                const res = await findDataInfo(this.infoParams)
                console.log('文档内容:', res)

                if (res && res.code === 200 && res.data) {
                    // wangeditor 直接输出 HTML，直接使用
                    this.info = res.data.content || ""
                } else {
                    console.warn('获取文档内容失败:', res)
                    this.info = ""
                }
            } catch (error) {
                console.error('获取文档内容失败:', error)
                this.info = ""
            }
        },
        

        

    }
}